@@ -23,14 +23,14 @@ class S3DirectEditor(widgets.TextInput):
 
     class Media:
         js = (
-            'ajaximage/js/jquery.iframe-transport.js',
-            'ajaximage/js/jquery.ui.widget.js',
-            'ajaximage/js/jquery.fileupload.js',
+            'shared-bg/js/jquery.iframe-transport.js',
+            'shared-bg/js/jquery.ui.widget.js',
+            'shared-bg/js/jquery.fileupload.js',
             's3direct/js/s3direct.js',
         )
         css = {
             'all': (
-                's3direct/css/bootstrap-progress.min.css',
+                'shared-bg/css/bootstrap-progress.min.css',
                 's3direct/css/styles.css',
             )
         }
@@ -55,4 +55,4 @@ class S3DirectEditor(widgets.TextInput):
                              element_id=element_id,
                              name=name)
 
-        return mark_safe(output)
\ No newline at end of file
+        return mark_safe(output)
